@@ -6,4 +6,4 @@ CREATE TABLE test (
   date_create TIMESTAMP NOT NULL,
   PRIMARY KEY  (id),
   KEY idx_actor_last_name (value2)
-)ENGINE=InnoDB DEFAULT CHARSET=utf8;
+)ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;
